% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/10_survival.R
\name{fit_survival}
\alias{fit_survival}
\alias{.plot_survival}
\alias{plot_survival}
\title{Fit/Plot survival}
\usage{
fit_survival(
  object,
  assay = assayNames(object)[1],
  percentile = 25,
  sep = FITSEP,
  samples = if (ncol(object) < 50) TRUE else FALSE,
  verbose = TRUE
)

.plot_survival(
  object,
  assay = assayNames(object)[1],
  percentile = 25,
  title = paste0(assay, " ", percentile, "\%"),
  subtitle = NULL,
  palette = c("#009999", "#ff5050")
)

plot_survival(
  object,
  assay = assayNames(object)[1],
  percentile = percentiles(object),
  title = paste0(assay, " ", percentile, "\%"),
  subtitle = NULL,
  palette = c("#009999", "#ff5050"),
  n = 4,
  ncol = 4,
  nrow = length(percentile),
  file = NULL,
  width = 7 * ncol,
  height = 7 * nrow
)
}
\arguments{
\item{object}{SummarizedExperiment}

\item{assay}{string}

\item{percentile}{percentage (not greater than 50)}

\item{sep}{fvar string separator : e.g. '~' gives p~surv~LR50}

\item{samples}{TRUE or FALSE : record which samples in which stratum ?}

\item{verbose}{TRUE or FALSE}

\item{title}{string}

\item{subtitle}{string}

\item{palette}{color vector}

\item{n}{number}

\item{ncol}{number}

\item{nrow}{number}

\item{file}{filepath}

\item{width}{number}

\item{height}{number}
}
\value{
ggsurvplot
}
\description{
Fit/Plot survival
}
\examples{
file <- download_tcga_example()
if (!is.null(file) & requireNamespace('survminer')){
# Read
    object <- readRDS(file)
    object \%<>\% extract(, .$sample_type == 'T')
    object \%<>\% extract(c('UGT3A2', 'NSUN3', 'XRCC4', 'WNT10A'), )
# Fit
    fdt(object)
    fdt(fit_survival(object))
    fdt(fit_survival(object, percentile = 50))
    fdt(fit_survival(object, percentile = 50, sep = '.'))
# Plot
    object \%<>\% fit_survival()
    plot_survival(object)
    p1 <- .plot_survival(object[1, ])
    p2 <- .plot_survival(object[2, ])
}
}
