% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/3.2_read_proteingroups.R
\name{read_maxquant_proteingroups}
\alias{read_maxquant_proteingroups}
\alias{read_proteingroups}
\title{Read maxquant proteingroups}
\usage{
read_maxquant_proteingroups(
  dir = getwd(),
  file = if (is_file(dir)) dir else file.path(dir, "proteinGroups.txt"),
  fastafile = NULL,
  restapi = FALSE,
  quantity = NULL,
  subgroups = NULL,
  invert = character(0),
  contaminants = FALSE,
  reverse = FALSE,
  rm_missing_in_all_samples = TRUE,
  impute = FALSE,
  plot = FALSE,
  label = "feature_id",
  pca = plot,
  pls = plot,
  fit = if (plot) "limma" else NULL,
  formula = ~subgroup,
  block = NULL,
  coefs = NULL,
  contrasts = NULL,
  palette = NULL,
  verbose = TRUE
)

read_proteingroups(...)
}
\arguments{
\item{dir}{proteingroups directory}

\item{file}{proteingroups file}

\item{fastafile}{uniprot fastafile}

\item{restapi}{TRUE or FALSE : use uniprot restapi to annotate uniprots not in fastadt ?}

\item{quantity}{'normalizedratio', 'ratio', 'correctedreporterintensity', 
'reporterintensity', 'maxlfq', 'labeledintensity', 
'intensity' or NULL}

\item{subgroups}{NULL or string vector : subgroups to retain}

\item{invert}{string vector : subgroups which require inversion}

\item{contaminants}{TRUE or FALSE : retain contaminants ?}

\item{reverse}{TRUE or FALSE : include reverse hits ?}

\item{rm_missing_in_all_samples}{TRUE or FALSE}

\item{impute}{TRUE or FALSE: impute group-specific NA values?}

\item{plot}{TRUE or FALSE: plot ?}

\item{label}{fvar}

\item{pca}{TRUE or FALSE: run pca ?}

\item{pls}{TRUE or FALSE: run pls ?}

\item{fit}{model engine: 'limma', 'lm', 'lme(r)', 'wilcoxon' or NULL}

\item{formula}{model formula}

\item{block}{model blockvar: string or NULL}

\item{coefs}{model coefficients    of interest: character vector or NULL}

\item{contrasts}{coefficient contrasts of interest: character vector or NULL}

\item{palette}{color palette : named character vector}

\item{verbose}{TRUE or FALSE : message ?}

\item{...}{maintain deprecated functions}
}
\value{
SummarizedExperiment
}
\description{
Read maxquant proteingroups
}
\examples{
# fukuda20 - LFQ
    file <- system.file('extdata/fukuda20.proteingroups.txt', package = 'autonomics')
    pro <- read_maxquant_proteingroups(file = file)
    
# billing19 - Normalized Ratios
    file <- system.file('extdata/billing19.proteingroups.txt', package = 'autonomics')
    fastafile <- system.file('extdata/uniprot_hsa_20140515.fasta', package = 'autonomics')
    subgroups <- sprintf('\%s_STD', c('E00', 'E01', 'E02', 'E05', 'E15', 'E30', 'M00'))
    pro <- read_maxquant_proteingroups(file = file, subgroups = subgroups)
    pro <- read_maxquant_proteingroups(file = file, fastafile = fastafile, subgroups = subgroups)
}
